@@ -27,7 +27,7 @@ include "inc/header.inc.php";
 
 
 //ACS check
-if (isset($_REQUEST['group_id'])) {
+if (!empty($_REQUEST['group_id'])) {
 	$group_id = $_REQUEST['group_id'];
 	include_once ('inc/header_group.inc.php');
 	
@@ -50,6 +50,7 @@ $blog = new Blog($db, null, null);
 $blog->rsp_level_id = $rsp_level_id;
 
 // SETUP LANGUAGE --------------------------------------------------------
+require_once($languagePath . 'common.lang.php');
 require_once($languageArrayPath . 'arr_user.lang.php');
 
 
@@ -136,7 +137,7 @@ elseif (isset($_POST['insert'])) {
 			$statistic->group_id = $frmdata['group_id'];
 			
 			//update group stats
-			unset($comment->user_id, $statistic->user_id, $comment->rsp_item_type_id, $comment->item_id);
+			unset($comment->user_id, $statistic->user_id, $comment->rsp_item_type_id, $comment->item_id, $comment->item_user_id);
 			$statistic->statistic_type_id = $c_node['statistic']['group']['total_comments'];
 			$statistic->setStatistic($comment->getCommentCount());
 			
@@ -232,8 +233,8 @@ elseif (isset($_REQUEST['view'])) {
 			endforeach;
 		}
 		
-		$lang['txt_intro_group'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_group']);
-		$lang['txt_outro_group'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_outro_group']);
+		$lang['txt_intro_group'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_group']);
+		$lang['txt_outro_group'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_outro_group']);
 		
 		$output_my_group_blogs = $mygroups;
 		
@@ -261,12 +262,15 @@ elseif (isset($_REQUEST['view'])) {
 		$user->file = $file;
 		$output_users = $user->selUsers();
 		
-		
+		// get the blogs published to network
+		$blog->rsp_item_type_id = $c_node['rsp']['item_type']['blog'];
+		$blog->rsp_level_id = $c_node['rsp']['rsp_level']['node'];
+		$blog->degree_id = 1;
 		$blog->limit = $c_node['display']['max_list_rows'];
 		$network_blogs = $blog->selBlogs();
 		
 		//sort blogs under people
-		if (!empty($output_users)) {
+		if (!empty($output_users) && !empty($network_blogs)) {
 			foreach ($output_users as $item_key => $i):
 				foreach($network_blogs as $content_key => $c):
 					if ($i['user_id'] == $c['user_id']) {
@@ -279,8 +283,8 @@ elseif (isset($_REQUEST['view'])) {
 		
 		$output_my_network_blogs = $output_users;
 		
-		$lang['txt_intro_network'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_network']);
-		$lang['txt_outro_network'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_outro_network']);
+		$lang['txt_intro_network'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_network']);
+		$lang['txt_outro_network'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_outro_network']);
 		
 		$menu_section = "network";
 	}
@@ -296,7 +300,7 @@ elseif (isset($_REQUEST['view'])) {
 		
 		$menu_section = "my";
 	}
-	elseif ($_REQUEST['view'] == "marked_blogs" && isset($me['user_id'])) {
+	elseif ($_REQUEST['view'] == "marked_blog_entries" && isset($me['user_id'])) {
 		//get my marked blogs
 		unset($blog->rsp_level_id);
 		$file->noimage = $c_node['file']['image']['thumb'][3]['noimage'];
@@ -307,12 +311,80 @@ elseif (isset($_REQUEST['view'])) {
 		$bookmark->rsp_item_type_id = $c_node['rsp']['item_type']['blog'];
 		$watched_blog_ids = $bookmark->getBookmarks();
 		
-		$blog->user_id = $me['user_id'];
-		
 		if (!empty($watched_blog_ids)) {
 			$blog->blog_ids = $watched_blog_ids;
 			$output_blogs = $blog->selBlogs();
 		}
+		
+		// remove blog entries written by me
+		if (!empty($output_blogs)) {
+			foreach($output_blogs as $key => $i):
+			echo $i['user_id'] . " ";
+				if ($me['user_id'] == $i['user_id']) {
+					unset ($output_blogs[$key]);
+				}
+			endforeach;
+		}
+		
+		$lang['txt_intro'] = $lang['txt_intro_marked'];
+	}
+	elseif ($_REQUEST['view'] == "tipped_blog_entries" && isset($me['user_id'])) {
+		//get my relations tipped blogs
+		unset($blog->rsp_level_id);
+		$file->noimage = $c_node['file']['image']['thumb'][3]['noimage'];
+		$file->thumb = $c_node['file']['image']['thumb'][3]['name'];
+		$blog->file = $file;
+		
+		unset($bookmark->user_id);
+		
+		$my_network = $_SESSION['relations'];
+		
+		if (!empty($my_network)) {
+			foreach($my_network as $key => $i):
+				$bookmark->user_ids[] = $i['user_id_relation'];
+				$user->user_ids[] = $i['user_id_relation'];
+			endforeach;
+		}
+		else {
+			$bookmark->user_ids[] = 0;
+			$user->user_ids[] = 0;
+		}
+		
+		$user->file = $file;
+		$output_users = $user->selUsers();
+		
+		
+		$bookmark->bookmark_type = $c_node['bookmark']['type']['recommend'];
+		$bookmark->rsp_item_type_id = $c_node['rsp']['item_type']['blog'];
+		$recommended_blog_ids = $bookmark->getBookmarks(1);
+		
+		if (!empty($recommended_blog_ids)) {
+			foreach($recommended_blog_ids as $key => $i):
+				$blog->blog_ids[] = $i['item_id'];
+			endforeach;
+			
+			$recommended_blogs = $blog->selBlogs();
+			
+			//sort blogs under people
+			if (!empty($output_users) && !empty($recommended_blogs)) {
+				foreach ($output_users as $item_key => $i): // for each user we get their tipped items
+					foreach($recommended_blog_ids as $bookmark_key => $b):
+						if ($i['user_id'] == $b['user_id']) {
+							// we get the blog
+							foreach($recommended_blogs as $content_key => $c):
+								if ($c['blog_id'] == $b['item_id']) {
+									$output_users[$item_key]['blogs'][] = $c;
+									unset ($recommended_blogs[$content_key]);
+								}
+							endforeach;
+						}
+					endforeach;
+				endforeach;
+			}
+			
+		}
+		$output_recommended_blogs = $output_users;
+		$lang['txt_intro'] = $lang['txt_intro_tipped'];
 	}
 }
 elseif (isset($_REQUEST['user_id'])) {
@@ -355,8 +427,6 @@ elseif (isset($_REQUEST['group_id'])) {
 	$file->thumb = $c_node['file']['image']['thumb'][3]['name'];
 	$blog->file = $file;
 	
-	unset($menu_section);
-	
 	$output_blogs = $blog->selBlogs();
 	
 }
@@ -370,11 +440,11 @@ else { // get the latest item published to node
 	
 	$output_blogs = $blog->selBlogs();
 	
-	$lang['txt_intro_node'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_node']);
-	
-	$menu_section = "magazine";
+	$lang['txt_intro_node'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_node']);
 	
 	$_REQUEST['view'] = "node";
+	
+	$menu_section = "magazine";
 }
 
 
@@ -387,7 +457,14 @@ if (!empty($output_blog)) {
 	$rsp = new Rsp($db, $c_node['rsp']['item_type']['blog']);
 	$output_blog['rsp'] = $rsp->selRspItem($blog->blog_id);
 	
-	if (!empty($output_blog['rsp'])) { // is the item set to public?
+	if (isset($me['user_id']) && $me['user_id'] == $output_blog['user_id']) {
+		// is the author me?
+		$allow_view = 1;
+	}
+	elseif (isset($rss_access_granted)) { // RSS Feed link
+		$allow_view = 1;
+	}
+	elseif (!empty($output_blog['rsp'])) { // is the item set to public?
 		foreach ($output_blog['rsp'] as $key => $i):
 			if ($i['level_id'] == $c_node['rsp']['rsp_level']['public']) {
 				$allow_view = 1;
@@ -411,10 +488,6 @@ if (!empty($output_blog)) {
 			}
 		endforeach;
 	}
-	elseif (isset($me['user_id']) && $me['user_id'] == $output_blog['user_id']) {
-		// is the author me?
-		$allow_view = 1;
-	}
 	
 	if (!empty($output_blog['group_id'])) {
 		require_once('class/Group.class.php');
@@ -448,9 +521,6 @@ if (!empty($output_blog)) {
 		}
 		
 		$blog->group_id = $output_blog['group_id'];
-		
-		unset($menu_section);
-		
 	}
 	
 	
@@ -464,9 +534,15 @@ if (!empty($output_blog)) {
 if (!empty($output_blog)) {
 	//wikify body
 	$wiki_path = "lib_view.php?page=";
-	$wiki_new_path = "lib_edit.php?page=";
 	$wiki_image_base = "get_file.php?file=";
 	
+	if (!empty($output_blog['group_id'])) {
+		$wiki_new_path = "lib_edit.php?group_id=" . $output_blog['group_id'] . "&page=";
+	}
+	else {
+		$wiki_new_path = "lib_edit.php?page=";
+	}
+	
 	$wiki->setRenderConf('xhtml', 'wikilink', 'view_url', $wiki_path);
 	$wiki->setRenderConf('xhtml', 'wikilink', 'new_url', $wiki_new_path);
 	$wiki->setRenderConf('xhtml', 'image', 'base', $wiki_image_base);
@@ -501,6 +577,10 @@ if (!empty($output_blog)) {
 	}
 	
 	//get comments
+	if (isset($_SESSION['user_preferences']['comment_mode']) && $_SESSION['user_preferences']['comment_mode'] == "normal_mode") {
+		$comment->no_comment_parent_id = 1;
+	}
+	
 	unset($comment->user_id);
 	if (!empty($output_blog['group_id'])) {
 		$comment->group_id = $output_blog['group_id'];
@@ -521,12 +601,18 @@ if (!empty($output_blog)) {
 	unset($tag->user_id);
 	$output_item_tags = $tag->selTags(1);
 	
-	
 	//get a list of the latest blogs for the side menu
 	$blog->user_id = $output_blog['user_id'];
 	$blog->limit = 10;
 	
 	$output_sidebar_blogs = $blog->selBlogs();
+	
+	if (!empty($output_blog['group_id'])) {
+		$menu_section = "group";
+	}
+	else {
+		$menu_section = "magazine";
+	}
 }
 
 
@@ -572,10 +658,12 @@ if (!empty($_REQUEST['view'])) {
 if (!empty($output_blog)) {
 	$body->set('blog', $output_blog);
 	$body->set('rsp_config', $c_node['rsp']);
+	$lang['nav_breadcrumb_note'] = $output_blog['blog_title'];
 }
 
 if (!empty($output_blogs)) {
 	$body->set('blogs', $output_blogs);
+	unset($lang['nav_breadcrumb']);
 }
 
 if (!empty($output_sidebar_blogs)) {
@@ -615,20 +703,17 @@ if (!empty($output_my_network_blogs)) {
 	$body->set('my_network_blogs', $output_my_network_blogs);
 }
 
-if (!empty($output_profile)) {
-	$body->set('profile', $output_profile);
+if (!empty($output_recommended_blogs)) {
+	$body->set('recommended_blogs', $output_recommended_blogs);
 }
 
-
-if (!empty($output_blog)) {
-	$template_pageLinkNote = $output_blog['blog_title'];
+if (!empty($output_profile)) {
+	$body->set('profile', $output_profile);
 }
 
 $body->set('batch_enabled', $c_node['batch']['enabled']);
 $body->set('rspconfig', $c_node['rsp']);
 
-$template_pageLink = $lang['txt_blog'];
-
 include "inc/footer.inc.php";
 
 ?>
\ No newline at end of file
