@@ -27,7 +27,7 @@ include "inc/header.inc.php";
 
 
 //ACS check
-if (isset($_REQUEST['group_id'])) {
+if (!empty($_REQUEST['group_id'])) {
 	$group_id = $_REQUEST['group_id'];
 	include_once ('inc/header_group.inc.php');
 	
@@ -45,6 +45,7 @@ elseif (!isset($rss_access_granted) && (!$user_acs->checkPermission($c_acs['arr_
 
 
 // SETUP LANGUAGE --------------------------------------------------------
+require_once($languagePath . 'common.lang.php');
 require_once($languageArrayPath . 'arr_user.lang.php');
 require_once($languageArrayPath . 'arr_acs.lang.php');
 
@@ -121,6 +122,9 @@ elseif (isset($_POST['preview'])) {
 	
 	$output_subject = $forum->selSubject();
 	
+	$forum->topic_id = $output_subject['topic_id'];
+	$output_topic = $forum->selTopic();
+	
 	$display = "preview_comment";
 
 }
@@ -148,7 +152,7 @@ elseif (isset($_POST['insert'])) {
 			$statistic->group_id = $frmdata['group_id'];
 			
 			//update group stats
-			unset($comment->user_id, $statistic->user_id, $comment->rsp_item_type_id, $comment->item_id);
+			unset($comment->user_id, $statistic->user_id, $comment->rsp_item_type_id, $comment->item_id, $comment->item_user_id);
 			$statistic->statistic_type_id = $c_node['statistic']['group']['total_comments'];
 			$statistic->setStatistic($comment->getCommentCount());
 			
@@ -251,8 +255,8 @@ elseif (isset($_REQUEST['view'])) {
 			endforeach;
 		}
 		
-		$lang['txt_intro_group'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_group']);
-		$lang['txt_outro_group'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_outro_group']);
+		$lang['txt_intro_group'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_group']);
+		$lang['txt_outro_group'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_outro_group']);
 		
 		$output_my_group_subjects = $mygroups;
 		
@@ -280,11 +284,15 @@ elseif (isset($_REQUEST['view'])) {
 		$user->file = $file;
 		$output_users = $user->selUsers();
 		
+		// get the subjects published to network
+		$forum->rsp_item_type_id = $c_node['rsp']['item_type']['forum'];
+		$forum->rsp_level_id = $c_node['rsp']['rsp_level']['node'];
+		$forum->degree_id = 1;
 		$forum->limit = $c_node['display']['max_list_rows'];
 		$network_subjects = $forum->selSubjects();
 		
 		//sort subjects under people
-		if (!empty($output_users)) {
+		if (!empty($output_users) && !empty($network_subjects)) {
 			foreach ($output_users as $item_key => $i):
 				foreach($network_subjects as $content_key => $c):
 					if ($i['user_id'] == $c['user_id']) {
@@ -297,12 +305,12 @@ elseif (isset($_REQUEST['view'])) {
 		
 		$output_my_network_subjects = $output_users;
 		
-		$lang['txt_intro_network'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_network']);
-		$lang['txt_outro_network'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_outro_network']);
+		$lang['txt_intro_network'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_network']);
+		$lang['txt_outro_network'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_outro_network']);
 		
 		$menu_section = "network";
 	}
-	elseif ($_REQUEST['view'] == "my_subject" && isset($me['user_id'])) {
+	elseif ($_REQUEST['view'] == "my_subjects" && isset($me['user_id'])) {
 		//get my subjects
 		unset($forum->rsp_level_id);
 		$file->noimage = $c_node['file']['image']['thumb'][3]['noimage'];
@@ -327,12 +335,80 @@ elseif (isset($_REQUEST['view'])) {
 		$bookmark->rsp_item_type_id = $c_node['rsp']['item_type']['forum'];
 		$watched_subject_ids = $bookmark->getBookmarks();
 		
-		$forum->user_id = $me['user_id'];
-		
 		if (!empty($watched_subject_ids)) {
 			$forum->subject_ids = $watched_subject_ids;
 			$output_subjects = $forum->selSubjects();
 		}
+		
+		// remove subjects written by me
+		if (!empty($output_subjects)) {
+			foreach($output_subjects as $key => $i):
+			echo $i['user_id'] . " ";
+				if ($me['user_id'] == $i['user_id']) {
+					unset ($output_subjects[$key]);
+				}
+			endforeach;
+		}
+		
+		$lang['txt_intro'] = $lang['txt_intro_marked'];
+	}
+	elseif ($_REQUEST['view'] == "tipped_subjects" && isset($me['user_id'])) {
+		//get my relations tipped subjects
+		unset($forum->rsp_level_id);
+		$file->noimage = $c_node['file']['image']['thumb'][3]['noimage'];
+		$file->thumb = $c_node['file']['image']['thumb'][3]['name'];
+		$forum->file = $file;
+		
+		unset($bookmark->user_id);
+		
+		$my_network = $_SESSION['relations'];
+		
+		if (!empty($my_network)) {
+			foreach($my_network as $key => $i):
+				$bookmark->user_ids[] = $i['user_id_relation'];
+				$user->user_ids[] = $i['user_id_relation'];
+			endforeach;
+		}
+		else {
+			$bookmark->user_ids[] = 0;
+			$user->user_ids[] = 0;
+		}
+		
+		$user->file = $file;
+		$output_users = $user->selUsers();
+		
+		
+		$bookmark->bookmark_type = $c_node['bookmark']['type']['recommend'];
+		$bookmark->rsp_item_type_id = $c_node['rsp']['item_type']['forum'];
+		$recommended_subject_ids = $bookmark->getBookmarks(1);
+		
+		if (!empty($recommended_subject_ids)) {
+			foreach($recommended_subject_ids as $key => $i):
+				$forum->subject_ids[] = $i['item_id'];
+			endforeach;
+			
+			$recommended_subjects = $forum->selSubjects();
+			
+			//sort blogs under people
+			if (!empty($output_users) && !empty($recommended_subjects)) {
+				foreach ($output_users as $item_key => $i): // for each user we get their tipped items
+					foreach($recommended_subject_ids as $bookmark_key => $b):
+						if ($i['user_id'] == $b['user_id']) {
+							// we get the blog
+							foreach($recommended_subjects as $content_key => $c):
+								if ($c['subject_id'] == $b['item_id']) {
+									$output_users[$item_key]['subjects'][] = $c;
+									unset ($recommended_subjects[$content_key]);
+								}
+							endforeach;
+						}
+					endforeach;
+				endforeach;
+			}
+			
+		}
+		$output_recommended_subjects = $output_users;
+		$lang['txt_intro'] = $lang['txt_intro_tipped'];
 	}
 }
 elseif (isset($_REQUEST['user_id'])) {
@@ -418,10 +494,14 @@ elseif (!empty($_REQUEST['group_id'])) {
 	unset($forum->topic_id);
 	$forum->limit=10;
 	$forum->order_by = "s.subject_create_datetime desc";
+	unset($forum->comment->user_id);
 	$output_subjects = $forum->selSubjects();
 	
 	// get comments --------------------------------------------------------
-	unset($comment->user_id);
+	if (isset($_SESSION['user_preferences']['comment_mode']) && $_SESSION['user_preferences']['comment_mode'] == "normal_mode") {
+		$comment->no_comment_parent_id = 1;
+	}
+	
 	$comment->group_id = $_REQUEST['group_id'];
 	$comment->limit = 10;
 	$comment->orderby = "c.comment_create_datetime desc";
@@ -439,7 +519,6 @@ else { //overview
 	
 	$forum->rsp_item_type_id = $c_node['rsp']['item_type']['forum'];
 	$forum->rsp_status_id = $c_node['rsp']['status']['live'];
-	$forum->rsp_level_id = $c_node['rsp']['rsp_level']['degree']; // published to everyone
 	
 	unset($forum->topic_id);
 	$forum->limit=10;
@@ -447,13 +526,23 @@ else { //overview
 	$output_subjects = $forum->selSubjects();
 	
 	
-	// get comments --------------------------------------------------------
-	unset($comment->user_id);
-	$comment->limit = 10;
-	$comment->orderby = "c.comment_create_datetime desc";
-	$output_comments = $comment->selComments();
+	// get the latest comment for the selected subjects ------------
+	if (!empty($output_subjects)) {
+		foreach ($output_subjects as $key => $i):
+			$comment->item_ids[] = $i['subject_id'];
+		endforeach;
+		
+		if (!isset($comment->item_ids)) {
+			$comment->item_ids[] = 0;
+		}
+		
+		unset($comment->user_id);
+		$comment->limit = 10;
+		$comment->orderby = "c.comment_create_datetime desc";
+		$output_comments = $comment->selComments();
+	}
 	
-	$lang['txt_intro_node'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_node']);
+	$lang['txt_intro_node'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_node']);
 	
 	$menu_section = "magazine";
 	$display = "latest";
@@ -476,19 +565,23 @@ if (!empty($output_subject)) {
 	$rsp = new Rsp($db, $c_node['rsp']['item_type']['forum']);
 	$output_subject['rsp'] = $rsp->selRspItem($output_subject['subject_id']);
 	
-	if (!empty($output_subject['rsp'])) { // is the item set to public?
+	if (isset($me['user_id']) && $me['user_id'] == $output_subject['user_id']) {
+		// is the author me?
+		$allow_view = 1;
+	}
+	elseif (isset($rss_access_granted)) { // RSS Feed link
+		$allow_view = 1;
+	}
+	elseif (!empty($output_subject['rsp'])) { // is the item set to public?
 		foreach ($output_subject['rsp'] as $key => $i):
 			if ($i['level_id'] == $c_node['rsp']['rsp_level']['public']) {
 				$allow_view = 1;
 				break;
 			}
-			elseif (!empty($_SESSION['s_md5']) && $i['level_id'] == $c_node['rsp']['rsp_level']['node']) { // is the item set to node and the user logged in?
+			elseif (!empty($_SESSION['s_md5']) && empty($i['degree_id']) && $i['level_id'] == $c_node['rsp']['rsp_level']['node']) { // is the item set to node and the user logged in?
 				$allow_view = 1;
 				break;
 			}
-			elseif ($i['level_id'] == $c_node['rsp']['rsp_level']['degree'] && empty($i['degree_id'])) { // is it set to network (everyone)?
-				$allow_view = 1;
-			}
 			elseif (!empty($i['degree_id'])) { // is it set to network and are they in my network?
 				foreach($_SESSION['relations'] as $key => $r):
 					if ($output_subject['user_id'] == $r['user_id_relation']) {
@@ -503,10 +596,6 @@ if (!empty($output_subject)) {
 			}
 		endforeach;
 	}
-	elseif (isset($me['user_id']) && $me['user_id'] == $output_subject['user_id']) {
-		// is the author me?
-		$allow_view = 1;
-	}
 	
 	if (!empty($output_subject['group_id'])) {
 		require_once('class/Group.class.php');
@@ -553,11 +642,30 @@ if (!empty($output_subject)) {
 
 // FORMAT SUBJECT -------------------------------------------------------
 if (isset($output_subject)) {
+	//wikify body
+	$wiki_path = "lib_view.php?page=";
+	$wiki_image_base = "get_file.php?file=";
+	
+	if (!empty($output_subject['group_id'])) {
+		$wiki_new_path = "lib_edit.php?group_id=" . $output_subject['group_id'] . "&page=";
+	}
+	else {
+		$wiki_new_path = "lib_edit.php?page=";
+	}
+	
+	$wiki->setRenderConf('xhtml', 'wikilink', 'view_url', $wiki_path);
+	$wiki->setRenderConf('xhtml', 'wikilink', 'new_url', $wiki_new_path);
+	$wiki->setRenderConf('xhtml', 'image', 'base', $wiki_image_base);
+	
 	$output_subject['display_subject_body'] = $wiki->transform($output_subject['subject_body'], 'Xhtml');
 	
 	// GET AUTHOR
-	if (!empty($output_blog['group_id'])) {
-		$output_author = $user->selProfile($output_group['member']['profile_id'], null);
+	if (!empty($output_subject['group_id'])) {
+		$output_group['author'] = $group->getGroupMembership($output_subject['user_id']);
+		
+		if (!empty($output_group['author']['profile_id'])) {
+			$output_author = $user->selProfile($output_group['author']['profile_id'], null);
+		}
 	}
 	else {
 		$output_author = $user->selProfile(null, $output_subject['user_id']);
@@ -584,7 +692,8 @@ if (isset($output_subject)) {
 	if (!empty($output_subject['group_id'])) {
 		$comment->group_id = $output_subject['group_id'];
 	}
-	$output_comments = $comment->selComments($forum->subject_id);
+	
+	$output_comments = $comment->selComments($output_subject['subject_id']);
 	
 	
 	//get subject image
@@ -600,6 +709,13 @@ if (isset($output_subject)) {
 	$output_my_tags = $tag->selTags();
 	unset($tag->user_id);
 	$output_item_tags = $tag->selTags(1);
+	
+	if (!empty($output_subject['group_id'])) {
+		$menu_section = "group";
+	}
+	else {
+		$menu_section = "magazine";
+	}
 }
 
 
@@ -620,10 +736,12 @@ if (!empty($_REQUEST['view'])) {
 if (!empty($output_subject)) {
 	$body->set('subject', $output_subject);
 	$body->set('rsp_config', $c_node['rsp']);
-}                                 
+	$lang['nav_breadcrumb_note'] = $output_subject['subject_title'];
+}
 
 if (!empty($output_subjects)) {
-	$body->set('subjects', $output_subjects);  
+	$body->set('subjects', $output_subjects);
+	unset($lang['nav_breadcrumb']);
 }
 
 if (!empty($output_topic)) {
@@ -679,17 +797,16 @@ if (!empty($output_my_network_subjects)) {
 	$body->set('my_network_subjects', $output_my_network_subjects);
 }
 
+if (!empty($output_recommended_subjects)) {
+	$body->set('recommended_subjects', $output_recommended_subjects);
+}
+
 if (!empty($output_profile)) {
 	$body->set('profile', $output_profile);
 }
 
-if (isset($output_subject['subject_id'])) {
-	$template_pageLinkNote = $output_subject['subject_title'];
-}
-
-$body->set('batch_enabled', $c_node['batch']['enabled']); 
-
-$template_pageLink = $lang['txt_forum'];
+$body->set('batch_enabled', $c_node['batch']['enabled']);
+$body->set('rspconfig', $c_node['rsp']);
 
 include "inc/footer.inc.php";
 
