@@ -32,7 +32,9 @@ if (!isset($me['user_id']) || $me['user_id'] < 1) {
 }
 
 
-//append language setup
+// SETUP LANGUAGE --------------------------------------------------------
+require_once($languagePath . 'common.lang.php');
+require_once($languagePath . 'my_common.lang.php');
 require_once($languageArrayPath . 'arr_language_name.lang.php');
 require_once($languageArrayPath . 'arr_homepage.lang.php');
 require_once($languageArrayPath . 'arr_rsp.lang.php');
@@ -62,6 +64,12 @@ elseif (isset($_REQUEST['update_membership'])) {
 		$user->insertLanguages($frmdata['language_ids']);
 		$_SESSION['language_ids'] = $frmdata['language_ids'];
 		$_SESSION['language_id'] = $frmdata['language_id'];
+		
+		if (isset($_SESSION['template_id']) && $_SESSION['template_id'] != $frmdata['template_id']) {
+			$output_template = $user->getTemplate($frmdata['template_id']);
+			$_SESSION['template_id'] = $output_template['template_title'];
+		}
+		
 		header("Location: my_membership.php?" . strip_tags(SID));
 		exit;
 	}
@@ -72,9 +80,11 @@ elseif (isset($_REQUEST['update_membership'])) {
 
 
 }
-elseif (isset($_REQUEST['update_email'])) {
+elseif (isset($_POST['update_email'])) {
+	$output_user = $user->getUser($me['user_id']);
+	
 	//update email
-	if(isset($frmdata['user_email1']) && ($frmdata['user_email1'] != $output_user['user_email'])) {
+	if(isset($output_user['user_email']) && isset($frmdata['user_email1']) && ($frmdata['user_email1'] != $output_user['user_email'])) {
 		if(empty($frmdata['user_email1']) || empty($frmdata['user_email2'])) {
 			$GLOBALS['am_error_log'][] = array(2, null, null);
 		}
@@ -98,49 +108,11 @@ elseif (isset($_REQUEST['update_email'])) {
 			$result = $db->Execute($query);
 
 			if (isset($result) && empty($result->fields)) {
-				//append class vars
-				$user->AROUNDMe_dir = "";
-				$user->language_dir = $c_node['node']['template_default_name'];
-
 				//we now reset the password and send an email with the new login details
-				$password = $user->createPassword();
-
-				$tmp = md5($password);
-
-				$feed_password = $user->createFeedPassword($tmp);
-
-				unset ($frmdata['user_password1'], $frmdata['user_password2']);
-
-				//set up mail
-				require_once('class//Mail/class.phpmailer.php');
-				$mail = new PHPMailer();
-				$mail->Host = 		$c_node['mail']['host'];
-				$mail->Port = 		$c_node['mail']['port'];
-				$mail->Mailer = 	$c_node['mail']['mailer'];
-				
-				if (isset($c_node['mail']['smtp']['username'])) {
-					$mail->SMTPAuth = true;
-					$mail->Username = $c_node['mail']['smtp']['username'];
-					$mail->Password = $c_node['mail']['smtp']['password'];
-				}
-				
-				$mail->From = 		$c_node['mail']['no_reply_address'];
-				$mail->FromName = 	$c_node['mail']['from_name'];
-				$mail->WordWrap = 	$c_node['mail']['wordwrap'];
-				$mail->Subject = 	$lang['subject_new_details'];
-				$mail->AddReplyTo($c_node['mail']['no_reply_address'], $lang['subject_noreply']);
-
-				$user->mail = $mail;
-
-				$user->template_id = $frmdata['template_id'];
-				$user->emailVerification($password, $frmdata['user_email1'], $frmdata['user_firstname'], $frmdata['language_id'], 'registration.txt.php', "");
-
 				$query = "
 					UPDATE " . $db->prefix . "_user SET
-					user_email = '" . $frmdata['user_email1'] . "',
-					user_password='" . $tmp . "',
-					user_feed_password='" . $feed_password . "',
-					status_id = " . $c_node['user']['status']['pending'] . "
+					user_email=" . $db->qstr($frmdata['user_email1'], get_magic_quotes_gpc()) . ", 
+					status_id=" . $c_node['user']['status']['dormant'] . "
 					WHERE
 					user_id=" . $me['user_id']
 				;
@@ -148,7 +120,7 @@ elseif (isset($_REQUEST['update_email'])) {
 				$db->Execute($query);
 
 				$user->logoffUser();
-				header("Location: index.php");
+				header("Location: spl_view.php?dormant=1");
 				exit;
 			}
 		}
@@ -180,6 +152,13 @@ else {
 	if (substr($url, -1, 1) != "/") {
 	    $url .= "/";
 	}
+	
+	$rss_public_url = $url . "rss_feed.php";
+	
+	if (isset($me['user_id']) && $me['user_id'] > 0) {
+		$rss_url = $url . "rss_feed.php?feed=" . $me['user_feed_password'] . $me['user_id'];
+	}
+
 	$rss_url = $url . "rss_feed.php?feed=" . $output_user['user_feed_password'] . $output_user['user_id'];
 
 
@@ -187,28 +166,37 @@ else {
 }
 
 if (isset($_REQUEST['update_user_preferences'])) {
-	$user->deletetUserPreference($c_node['user']['preference']['email_message']);
-	$user->deletetUserPreference($c_node['user']['preference']['digest_newsletter']);
+	$user->deletetUserPreference(null, $me['user_id']);
 	
 	if (isset($frmdata['user_preferences'])) {
 		foreach ($frmdata['user_preferences'] as $key => $i):
-			$user->insertUserPreference($i, $me['user_id']);
+			$user->insertUserPreference($key, $me['user_id'], $i);
 		endforeach;
 	}
 }
 
 //ACS check - we may not be allowed to set the network page as our homepage
-if (!$user_acs->checkPermission($c_acs['arr_acs']['resource']['node']['network'], $c_acs['arr_acs']['privilege']['allow_access'])) { //resourece_id, Priv_id
-	unset($lang['homepage']['page'][7]);
+if (!$user_acs->checkPermission($c_acs['arr_acs']['resource']['node']['network'], $c_acs['arr_acs']['privilege']['allow_network'])) { //resourece_id, Priv_id
+	unset($lang['homepage']['page'][6]);
 }
 
 
 $output_user['preferences'] = $user->selUserPreferences();
 
+// if no cron remove cron based preferences
+if (!isset($c_node['batch']['enabled']) || $c_node['batch']['enabled'] != true) {
+	unset($lang['user']['preference'][$c_node['user']['preference']['digest_newsletter']]);
+}
+
+
 $output_template = $user->getTemplates();
 
 
 //move to template
+if (!empty($rss_public_url)) {
+	$body->set('rss_public_url', $rss_public_url);
+}
+
 if (!empty($output_user)) {
    $body->set('user', $output_user);
 }
@@ -232,8 +220,7 @@ if (!empty($rss_url)) {
 $body->set('rsp_item_type_ids', $c_node['rsp']['item_type']);
 $body->set('user_preference_ids', $c_node['user']['preference']);
 $body->set('datedropdown', $date->dateDropdown($output_user['user_dob']));
-$body->set('cron_enabled', $c_node['batch']['enabled']);
-
+$body->set('batch_enabled', $c_node['batch']['enabled']);
 
 include "inc/footer.inc.php";
 
