@@ -32,6 +32,10 @@ if (!empty($_POST['group_id'])) { // page under group section
 	require_once($languagePath . 'grp_common.lang.php');
 }
 
+// SETUP LANGUAGE --------------------------------------------------------
+require_once($languagePath . 'common.lang.php');
+
+
 // SETUP TAGS
 require_once('class/Tag.class.php');
 $tag = new Tag($db, null);
@@ -379,10 +383,9 @@ if (!empty($output_users)) {
 
 if (!empty($search_text)) {
     $body->set('search_text', $search_text);
-	$lang['txt_search_results'] = str_replace("SEARCHTEXT", "\"" . $search_text . "\"", $lang['txt_search_results']);
+	$lang['txt_search_results'] = str_replace("SYS_KEYWORD_SEARCHTXT", "\"" . $search_text . "\"", $lang['txt_search_results']);
 }
 
-$template_pageLink = $lang['txt_search'];
 include "inc/footer.inc.php";
 
 ?>
